@@ -6,8 +6,8 @@ sub specs {
 
     return {
 
-        code          => "5294",
-        description   => "Round Labels",
+        code          => '5294',
+        description   => 'Round Labels',
 
         sheet_width   => 8.5,
         sheet_height  => 11,
@@ -23,7 +23,7 @@ sub specs {
         margin_right  => 0.266,
         margin_bottom => 0.516,
 
-        units         => "in",
+        units         => 'in',
 
     };
 
