@@ -6,8 +6,8 @@ sub specs {
 
     return {
 
-        code          => "5305",
-        description   => "Tent Card - Medium",
+        code          => '5305',
+        description   => 'Tent Card - Medium',
 
         sheet_width   => 8.5,
         sheet_height  => 11,
@@ -23,7 +23,7 @@ sub specs {
         margin_right  => 0.375,
         margin_bottom => 0.875,
 
-        units         => "in",
+        units         => 'in',
 
     };
 
