@@ -6,8 +6,8 @@ sub specs {
 
     return {
 
-        code          => "5889",
-        description   => "Color Laser Postcards",
+        code          => '5889',
+        description   => 'Color Laser Postcards',
 
         sheet_width   => 8.5,
         sheet_height  => 11,
@@ -23,7 +23,7 @@ sub specs {
         margin_right  => 1.25,
         margin_bottom => 1.25,
 
-        units         => "in",
+        units         => 'in',
 
     };
 
