@@ -6,7 +6,7 @@ use base qw(Paper::Specs::base::sheet);
 use vars qw($VERSION);
 $VERSION=0.01;
 
-sub type { return "label" }
+sub type { return 'label' }
 
 # No unit conversion support yet
 
@@ -51,7 +51,7 @@ sub label_location {
     my $pos_row = $self->margin_top + ($self->label_height + $self->gutter_rows) * ( $r - 1 );
     my $pos_col = $self->margin_left + ($self->label_width + $self->gutter_cols) * ( $c - 1 );
 
-    if ( Paper::Specs->layout eq "pdf" ) {
+    if ( Paper::Specs->layout eq 'pdf' ) {
 
         return ( $pos_col, $self->sheet_height - $pos_row );
 
@@ -66,7 +66,7 @@ sub label_size {
 
     my $self=shift;
 
-    if ( Paper::Specs->layout eq "pdf" ) {
+    if ( Paper::Specs->layout eq 'pdf' ) {
         return ( $self->label_width, -$self->label_height );
     } else {
         return ( $self->label_width, $self->label_height );
