@@ -12,8 +12,8 @@ Standard / well known paper formats
 sub specs {
 
     return {
-        name_short => "standard",
-        name_long  => "Standard paper sizes",
+        name_short => 'standard',
+        name_long  => 'Standard paper sizes',
     };
 
 }
